<?php
if ( ! class_exists( 'Rion_Visual_Composer' ) ) {
	class Rion_Visual_Composer {
		public function __construct() {
			$this->define_constants();
			add_filter( 'vc_google_fonts_get_fonts_filter', array( $this, 'vc_fonts' ) );
			$this->params();
			$this->autocomplete();
			/* Custom font Icon*/
			add_filter( 'vc_iconpicker-type-rioncustomfonts', array( &$this, 'iconpicker_type_rion_customfonts' ) );
			$this->map_shortcode();
		}

		/**
		 * Define  Constants.
		 */
		private function define_constants() {
			$this->define( 'RION_SHORTCODE_PREVIEW', get_theme_file_uri( '/framework/assets/images/shortcode-previews/' ) );
			$this->define( 'RION_SHORTCODES_ICONS_URI', get_theme_file_uri( '/framework/assets/images/vc-shortcodes-icons/' ) );
			$this->define( 'RION_PRODUCT_STYLE_PREVIEW', get_theme_file_uri( '/woocommerce/product-styles/' ) );
		}

		/**
		 * Define constant if not already set.
		 *
		 * @param  string      $name
		 * @param  string|bool $value
		 */
		private function define( $name, $value ) {
			if ( ! defined( $name ) ) {
				define( $name, $value );
			}
		}

		function params() {
			if ( function_exists( 'rion_toolkit_vc_param' ) ) {
				rion_toolkit_vc_param( 'taxonomy', array( $this, 'taxonomy_field' ) );
				rion_toolkit_vc_param( 'uniqid', array( $this, 'uniqid_field' ) );
				rion_toolkit_vc_param( 'select_preview', array( $this, 'select_preview_field' ) );
				rion_toolkit_vc_param( 'number', array( $this, 'number_field' ) );
			}
		}

		/**
		 * load param autocomplete render
		 * */
		public function autocomplete() {
			add_filter( 'vc_autocomplete_rion_products_ids_callback', array(
				$this,
				'productIdAutocompleteSuggester'
			), 10, 1 );
			add_filter( 'vc_autocomplete_rion_products_ids_render', array(
				$this,
				'productIdAutocompleteRender'
			), 10, 1 );
			add_filter( 'vc_autocomplete_rion_pinmap_ids_callback', array(
				$this,
				'pinmapIdAutocompleteSuggester'
			), 10, 1 );
			add_filter( 'vc_autocomplete_rion_pinmap_ids_render', array(
				$this,
				'pinmapIdAutocompleteRender'
			), 10, 1 );

		}

		/*
         * taxonomy_field
         * */
		public function taxonomy_field( $settings, $value ) {
			$dependency = '';
			$value_arr  = $value;
			if ( ! is_array( $value_arr ) ) {
				$value_arr = array_map( 'trim', explode( ',', $value_arr ) );
			}
			$output = '';
			if ( isset( $settings['hide_empty'] ) && $settings['hide_empty'] ) {
				$settings['hide_empty'] = 1;
			} else {
				$settings['hide_empty'] = 0;
			}
			if ( ! empty( $settings['taxonomy'] ) ) {
				$terms_fields = array();
				if ( isset( $settings['placeholder'] ) && $settings['placeholder'] ) {
					$terms_fields[] = "<option value=''>" . $settings['placeholder'] . "</option>";
				}
				$terms = get_terms( $settings['taxonomy'], array(
					'parent'     => $settings['parent'],
					'hide_empty' => $settings['hide_empty']
				) );
				if ( $terms && ! is_wp_error( $terms ) ) {
					foreach ( $terms as $term ) {
						$selected       = ( in_array( $term->slug, $value_arr ) ) ? ' selected="selected"' : '';
						$terms_fields[] = "<option value='{$term->slug}' {$selected}>{$term->name}</option>";
					}
				}
				$size     = ( ! empty( $settings['size'] ) ) ? 'size="' . $settings['size'] . '"' : '';
				$multiple = ( ! empty( $settings['multiple'] ) ) ? 'multiple="multiple"' : '';
				$uniqeID  = uniqid();
				$output   = '<select style="width:100%;" id="vc_taxonomy-' . $uniqeID . '" ' . $multiple . ' ' . $size . ' name="' . $settings['param_name'] . '" class="rion_vc_taxonomy wpb_vc_param_value wpb-input wpb-select ' . $settings['param_name'] . ' ' . $settings['type'] . '_field" ' . $dependency . '>'
				            . implode( $terms_fields )
				            . '</select>';
			}

			return $output;
		}

		public function uniqid_field( $settings, $value ) {
			if ( ! $value ) {
				$value = uniqid( hash( 'crc32', $settings['param_name'] ) . '-' );
			}
			$output = '<input type="text" class="wpb_vc_param_value textfield" name="' . $settings['param_name'] . '" value="' . esc_attr( $value ) . '" />';

			return $output;
		}

		public function number_field( $settings, $value ) {
			$dependency = '';
			$param_name = isset( $settings['param_name'] ) ? $settings['param_name'] : '';
			$type       = isset( $settings['type '] ) ? $settings['type'] : '';
			$min        = isset( $settings['min'] ) ? $settings['min'] : '';
			$max        = isset( $settings['max'] ) ? $settings['max'] : '';
			$suffix     = isset( $settings['suffix'] ) ? $settings['suffix'] : '';
			$class      = isset( $settings['class'] ) ? $settings['class'] : '';
			if ( ! $value && isset( $settings['std'] ) ) {
				$value = $settings['std'];
			}
			$output = '<input type="number" min="' . esc_attr( $min ) . '" max="' . esc_attr( $max ) . '" class="wpb_vc_param_value textfield ' . $param_name . ' ' . $type . ' ' . $class . '" name="' . $param_name . '" value="' . esc_attr( $value ) . '" ' . $dependency . ' style="max-width:100px; margin-right: 10px;" />' . $suffix;

			return $output;
		}

		public function select_preview_field( $settings, $value ) {
			ob_start();
			// Get menus list
			$options = $settings['value'];
			$default = $settings['default'];
			if ( is_array( $options ) && count( $options ) > 0 ) {
				$uniqeID = uniqid();
				$i       = 0;
				?>
                <div class="container-select_preview">
                    <select id="rion_select_preview-<?php echo esc_attr( $uniqeID ); ?>"
                            name="<?php echo esc_attr( $settings['param_name'] ); ?>"
                            class="rion_select_preview vc_select_image wpb_vc_param_value wpb-input wpb-select <?php echo esc_attr( $settings['param_name'] ); ?> <?php echo esc_attr( $settings['type'] ); ?>_field">
						<?php foreach ( $options as $k => $option ): ?>
							<?php
							if ( $i == 0 ) {
								$first_value = $k;
							}
							$i ++;
							?>
							<?php $selected = ( $k == $value ) ? ' selected="selected"' : ''; ?>
                            <option data-img="<?php echo esc_url( $option['img'] ); ?>"
                                    value='<?php echo esc_attr( $k ) ?>' <?php echo esc_attr( $selected ) ?>><?php echo esc_attr( $option['alt'] ) ?></option>
						<?php endforeach; ?>
                    </select>
                    <div class="image-preview">
						<?php if ( isset( $options[ $value ] ) && $options[ $value ] && ( isset( $options[ $value ]['img'] ) ) ): ?>
                            <img style="margin-top: 10px; max-width: 100%;height: auto;"
                                 src="<?php echo esc_url( $options[ $value ]['img'] ); ?>">
						<?php else: ?>
                            <img style="margin-top: 10px; max-width: 100%;height: auto;"
                                 src="<?php echo esc_url( $options[ $default ]['img'] ); ?>">
						<?php endif; ?>
                    </div>
                </div>
				<?php
			}

			return ob_get_clean();
		}

		/**
		 * Suggester for autocomplete by id/name/title/sku
		 *
		 * @since  1.0
		 *
		 * @param $query
		 *
		 * @author Reapple
		 * @return array - id's from products with title/sku.
		 */
		public function productIdAutocompleteSuggester( $query ) {
			global $wpdb;
			$product_id      = (int) $query;
			$post_meta_infos = $wpdb->get_results( $wpdb->prepare( "SELECT a.ID AS id, a.post_title AS title, b.meta_value AS sku
    					FROM {$wpdb->posts} AS a
    					LEFT JOIN ( SELECT meta_value, post_id  FROM {$wpdb->postmeta} WHERE `meta_key` = '_sku' ) AS b ON b.post_id = a.ID
    					WHERE a.post_type = 'product' AND ( a.ID = '%d' OR b.meta_value LIKE '%%%s%%' OR a.post_title LIKE '%%%s%%' )", $product_id > 0 ? $product_id : - 1, stripslashes( $query ), stripslashes( $query )
			), ARRAY_A
			);
			$results         = array();
			if ( is_array( $post_meta_infos ) && ! empty( $post_meta_infos ) ) {
				foreach ( $post_meta_infos as $value ) {
					$data          = array();
					$data['value'] = $value['id'];
					$data['label'] = esc_html__( 'Id', 'rion' ) . ': ' . $value['id'] . ( ( strlen( $value['title'] ) > 0 ) ? ' - ' . esc_html__( 'Title', 'rion' ) . ': ' . $value['title'] : '' ) . ( ( strlen( $value['sku'] ) > 0 ) ? ' - ' . esc_html__( 'Sku', 'rion' ) . ': ' . $value['sku'] : '' );
					$results[]     = $data;
				}
			}

			return $results;
		}

		/**
		 * Find product by id
		 *
		 * @since  1.0
		 *
		 * @param $query
		 *
		 * @author Reapple
		 *
		 * @return bool|array
		 */
		public function productIdAutocompleteRender( $query ) {
			$query = trim( $query['value'] ); // get value from requested
			if ( ! empty( $query ) ) {
				// get product
				$product_object = wc_get_product( (int) $query );
				if ( is_object( $product_object ) ) {
					$product_sku         = $product_object->get_sku();
					$product_title       = $product_object->get_title();
					$product_id          = $product_object->get_id();
					$product_sku_display = '';
					if ( ! empty( $product_sku ) ) {
						$product_sku_display = ' - ' . esc_html__( 'Sku', 'rion' ) . ': ' . $product_sku;
					}
					$product_title_display = '';
					if ( ! empty( $product_title ) ) {
						$product_title_display = ' - ' . esc_html__( 'Title', 'rion' ) . ': ' . $product_title;
					}
					$product_id_display = esc_html__( 'Id', 'rion' ) . ': ' . $product_id;
					$data               = array();
					$data['value']      = $product_id;
					$data['label']      = $product_id_display . $product_title_display . $product_sku_display;

					return ! empty( $data ) ? $data : false;
				}

				return false;
			}

			return false;
		}

		/**
		 * Suggester for autocomplete by id/name/title
		 *
		 * @since  1.0
		 *
		 * @param $query
		 *
		 * @author Reapple
		 * @return array - id's from post_types with title/.
		 */
		public function pinmapIdAutocompleteSuggester( $query ) {
			global $wpdb;
			$post_type_id    = (int) $query;
			$post_meta_infos = $wpdb->get_results( $wpdb->prepare( "SELECT a.ID AS id, a.post_title AS title 
    					FROM {$wpdb->posts} AS a 
    					WHERE a.post_type = 'rion_mapper' AND ( a.ID = '%d' OR a.post_title LIKE '%%%s%%' )", $post_type_id > 0 ? $post_type_id : - 1, stripslashes( $query ), stripslashes( $query )
			), ARRAY_A
			);
			$results         = array();
			if ( is_array( $post_meta_infos ) && ! empty( $post_meta_infos ) ) {
				foreach ( $post_meta_infos as $value ) {
					$data          = array();
					$data['value'] = $value['id'];
					$data['label'] = esc_html__( 'Id', 'rion' ) . ': ' . $value['id'] . ( ( strlen( $value['title'] ) > 0 ) ? ' - ' . esc_html__( 'Title', 'rion' ) . ': ' . $value['title'] : '' );
					$results[]     = $data;
				}
			}

			return $results;
		}

		/**
		 * Find product by id
		 *
		 * @since  1.0
		 *
		 * @param $query
		 *
		 * @author Reapple
		 *
		 * @return bool|array
		 */
		public function pinmapIdAutocompleteRender( $query ) {
			$query = trim( $query['value'] ); // get value from requested
			if ( ! empty( $query ) ) {
				// get post_type
				$post_type_object = wc_get_post_type( (int) $query );
				if ( is_object( $post_type_object ) ) {
					$post_type_title = $post_type_object->get_title();
					$post_type_id    = $post_type_object->get_id();

					$post_type_title_display = '';
					if ( ! empty( $post_type_title ) ) {
						$post_type_title_display = ' - ' . esc_html__( 'Title', 'rion' ) . ': ' . $post_type_title;
					}
					$post_type_id_display = esc_html__( 'Id', 'rion' ) . ': ' . $post_type_id;
					$data                 = array();
					$data['value']        = $post_type_id;
					$data['label']        = $post_type_id_display . $post_type_title_display;

					return ! empty( $data ) ? $data : false;
				}

				return false;
			}

			return false;
		}

		public function vc_fonts( $fonts_list ) {
			/* Cormorant Garamond */
			$Cormorant_Garamond              = new stdClass();
			$Cormorant_Garamond->font_family = "Cormorant Garamond";
			$Cormorant_Garamond->font_styles = "300,300i,400,400i,500,500i,600,600i,700,700i";
			$Cormorant_Garamond->font_types  = "300 light :300:normal,300 light italic :300:italic,400 regular :400:normal,400 regular italic :400:italic,500 medium :500:normal,500 medium italic :500:italic,600 semi-bold :600:normal,600 semi-bold italic :600:italic,700 bold :700:normal,700 bold italic :700:italic";

			$fonts = array( $Cormorant_Garamond );

			return array_merge( $fonts_list, $fonts );
		}

		/* Custom Font icon*/
		function iconpicker_type_rion_customfonts( $icons ) {
			$icons['Flaticon'] = array(
				array('flaticon-magnifying-glass'=>'Flaticon magnifying glass'),
				array('flaticon-profile'=>'Flaticon profile'),
				array('flaticon-bag'=>'Flaticon bag'),
				array('flaticon-right-arrow'=>'Flaticon right arrow'),
				array('flaticon-left-arrow'=>'Flaticon left arrow'),
				array('flaticon-right-arrow-1'=>'Flaticon right arrow 1'),
				array('flaticon-left-arrow-1'=>'Flaticon left arrow 1'),
				array('flaticon-mail'=>'Flaticon mail'),
				array('flaticon-flame'=>'Flaticon flame'),
				array('flaticon-clock'=>'Flaticon clock'),
				array('flaticon-comment'=>'Flaticon comment'),
				array('flaticon-chat'=>'Flaticon chat'),
				array('flaticon-heart'=>'Flaticon heart'),
				array('flaticon-valentines-heart'=>'Flaticon valentines heart'),
				array('flaticon-filter'=>'Flaticon filter'),
				array('flaticon-loading'=>'Flaticon loading'),
				array('flaticon-checked'=>'Flaticon checked'),
				array('flaticon-tick'=>'Flaticon tick'),
				array('flaticon-close'=>'Flaticon close'),
				array('flaticon-circular-check-button'=>'Flaticon circular check button'),
				array('flaticon-check'=>'Flaticon check'),
				array('flaticon-play-button'=>'Flaticon play button'),
				array('flaticon-360-degrees'=>'Flaticon 360 degrees'),
				array('flaticon-login'=>'Flaticon login'),
				array('flaticon-menu'=>'Flaticon menu'),
				array('flaticon-menu-1'=>'Flaticon menu 1'),
				array('flaticon-placeholder'=>'Flaticon placeholder'),
				array('flaticon-metre'=>'Flaticon metre'),
				array('flaticon-share'=>'Flaticon share'),
				array('flaticon-shuffle'=>'Flaticon shuffle'),
				array('flaticon-running'=>'Flaticon running'),
				array('flaticon-recycle'=>'Flaticon recycle'),
				array('flaticon-instagram'=>'Flaticon instagram'),
				array('flaticon-delivery-truck'=>'Flaticon delivery truck'),
				array('flaticon-closed-lock'=>'Flaticon closed lock'),
				array('flaticon-support'=>'Flaticon support'),
				array('flaticon-diamond'=>'Flaticon diamond'),
				array('flaticon-high-heels'=>'Flaticon high heels'),
				array('flaticon-shirt'=>'Flaticon shirt'),
				array('flaticon-dress'=>'Flaticon dress'),
				array('flaticon-shirt-1'=>'Flaticon shirt 1'),
				array('flaticon-glasses'=>'Flaticon glasses'),
				array('flaticon-shopping-bag'=>'Flaticon shopping bag'),
				array('flaticon-trousers'=>'Flaticon trousers'),
				array('flaticon-user'=>'Flaticon user'),
				array('flaticon-magnifying-glass-1'=>'Flaticon magnifying glass 1'),
				array('flaticon-shopping-bag-1'=>'Flaticon shopping bag 1'),
				array('flaticon-envelope'=>'Flaticon envelope'),
				array('flaticon-instagram-1'=>'Flaticon instagram 1'),
				array('flaticon-rocket-ship'=>'Flaticon rocket ship'),
				array('flaticon-refresh'=>'Flaticon refresh'),
				array('flaticon-return'=>'Flaticon return'),
				array('flaticon-padlock'=>'Flaticon padlock'),
				array('flaticon-random'=>'Flaticon random'),
				array('flaticon-shopping-cart'=>'Flaticon shopping cart'),
				array('flaticon-cart'=>'Flaticon cart'),
				array('flaticon-filter-1'=>'Flaticon filter 1'),
				array('flaticon-startup'=>'Flaticon startup'),
				array('flaticon-return-1'=>'Flaticon return 1'),
				array('flaticon-letter'=>'Flaticon letter'),
				array('flaticon-diamond-1'=>'Flaticon diamond 1'),
			);

			return $icons;
		}

		public function animation_on_scroll() {
		    return array(
			    esc_html__( 'None', 'rion' )      => '',
			    esc_html__( 'Smooth Up', 'rion' ) => 'rion-wow fadeInUp',
			    esc_html__( 'Smooth Down', 'rion' ) => 'rion-wow fadeInDown',
			    esc_html__( 'Smooth Left', 'rion' ) => 'rion-wow fadeInLeft',
			    esc_html__( 'Smooth Right', 'rion' ) => 'rion-wow fadeInRight',
		    );
        }

		public function map_shortcode() {
			/* Map New Banner */
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Banner', 'rion' ),
					'base'        => 'rion_banner', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a Banner list.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'banner.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-01.jpg',
								),
								'style-02' => array(
									'alt' => 'Style 02', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-02.jpg',
								),
                                'style-03' => array(
									'alt' => 'Style 03', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-03.jpg',
								),
								'style-04' => array(
									'alt' => 'Style 04', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-04.jpg',
								),
                                'style-05' => array(
									'alt' => 'Style 05', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-05.jpg',
								),
                                'style-06' => array(
									'alt' => 'Style 06', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-06.jpg',
								),
                                'style-07' => array(
									'alt' => 'Style 07', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-07.jpg',
								),
								'style-08' => array(
									'alt' => 'Style 08', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-08.jpg',
								),
                                'style-09' => array(
									'alt' => 'Style 09', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-09.jpg',
								),
								'style-10' => array(
									'alt' => 'Style 10', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-10.jpg',
								),
								'style-11' => array(
									'alt' => 'Style 11', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'banner/style-11.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Text Align', 'rion' ),
							'value'      => array(
								esc_html__( 'Left', 'rion' )   => '',
								esc_html__( 'Center', 'rion' ) => 'center',
								esc_html__( 'Right', 'rion' )  => 'right',
							),
							'param_name' => 'align',
							'std'        => '',
							'dependency'=> array(
								'element' => 'style',
								'value'   => array( 'style-01' ),
							),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Heading', 'rion' ),
							'param_name'  => 'heading',
							'description' => esc_html__( 'The title of shortcode', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array(
									'style-01',
								),
							),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'description' => esc_html__( 'The title of shortcode', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array(
                                    'style-01',
                                    'style-09',
                                    'style-10',
								),
							),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Big Title', 'rion' ),
							'param_name'  => 'bigtitle',
							'description' => esc_html__( 'The big title of shortcode', 'rion' ),
                            'admin_label' => true,
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Subtitle', 'rion' ),
							'param_name'  => 'subtitle',
							'description' => esc_html__( 'The subtitle of shortcode', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array(
									'style-02',
								),
							),
						),
						array(
							'type'       => 'textfield',
							'heading'    => esc_html__( 'Description', 'rion' ),
							'param_name' => 'desc',
                            'dependency'  => array(
                                'element' => 'style',
                                'value'   => array(
                                    'style-04',
                                    'style-05',
                                    'style-07',
                                    'style-08',
                                    'style-10',
                                ),
                            ),
						),
						array(
							'type'        => 'vc_link',
							'heading'     => esc_html__( 'Banner Link', 'rion' ),
							'param_name'  => 'link',
							'description' => esc_html__( 'Add banner link.', 'rion' ),
						),
						array(
							"type"        => "attach_image",
							"heading"     => esc_html__( "Image", "rion" ),
							"param_name"  => "image",
							"admin_label" => false,
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Active link image', 'rion' ),
							'value'      => array(
								esc_html__( 'No', 'rion' )  => '',
								esc_html__( 'Yes', 'rion' ) => 'yes',
							),
							'param_name' => 'linkimage',
							'std'        => '',
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'banner_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			/* Map New blog */
			$categories_array = array(
				esc_html__( 'All', 'rion' ) => '',
			);
			$args             = array();
			$categories       = get_categories( $args );
			foreach ( $categories as $category ) {
				$categories_array[ $category->name ] = $category->slug;
			}

			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Blog', 'rion' ),
					'base'        => 'rion_blog', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a blog list.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'blog.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'blog/style-01.jpg',
								),
                                'style-02' => array(
									'alt' => 'Style 02',
									'img' => RION_SHORTCODE_PREVIEW . 'blog/style-02.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'description' => esc_html__( 'The title of shortcode', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array('style-01'),
							),
						),
						array(
							'type' => 'loop',
							'heading' => esc_html__('Option Query', 'rion'),
							'param_name' => 'loop_query',
							'save_always' => true,
							'value' => 'post_type:post|size:10|order_by:date',
							'settings' => array(
								'size' => array(
									'hidden' => false,
									'value' => 6,
								),
								'order_by' => array('value' => 'date'),
							),
							'description' => esc_html__('Create WordPress loop, to populate content from your site.', 'rion'),
						),
						/* Owl */
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Yes', 'rion' ) => 'true',
								esc_html__( 'No', 'rion' )  => 'false',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'AutoPlay', 'rion' ),
							'param_name'  => 'autoplay',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'No', 'rion' )  => 'false',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Navigation', 'rion' ),
							'param_name'  => 'navigation',
							'description' => esc_html__( "Show buton 'next' and 'prev' buttons.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Center', 'rion' )  => '',
								esc_html__( 'Center Square', 'rion' ) => 'nav-center-square',
								esc_html__( 'Right', 'rion' ) => 'nav-right',
							),
							'std'         => '',
							'heading'     => esc_html__( 'Navigation type', 'rion' ),
							'param_name'  => 'nav_type',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							'dependency'  => array(
								'element' => 'navigation',
								'value'   => array( 'true' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'No', 'rion' )  => 'false',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Enable Dots', 'rion' ),
							'param_name'  => 'dots',
							'description' => esc_html__( "Show buton dots.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Default', 'rion' )  => '',
								esc_html__( 'Light', 'rion' ) => 'dots-light',
								esc_html__( 'Dark', 'rion' ) => 'dots-dark',
							),
							'std'         => '',
							'heading'     => esc_html__( 'Dots color', 'rion' ),
							'param_name'  => 'dots_color',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							'dependency'  => array(
								'element' => 'dots',
								'value'   => array( 'true' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Yes', 'rion' ) => 'true',
								esc_html__( 'No', 'rion' )  => 'false',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Loop', 'rion' ),
							'param_name'  => 'loop',
							'description' => esc_html__( "Inifnity loop. Duplicate last and first items to get loop illusion.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Slide Speed", 'rion' ),
							"param_name"  => "slidespeed",
							"value"       => "200",
							"description" => esc_html__( 'Slide speed in milliseconds', 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Margin", 'rion' ),
							"param_name"  => "margin",
							"value"       => "30",
							"description" => esc_html__( 'Distance( or space) between 2 item', 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Auto Responsive Margin', 'rion' ),
							'param_name' => 'autoresponsive',
							'group'      => esc_html__( 'Carousel settings', 'rion' ),
							'value'      => array(
								esc_html__( 'No', 'rion' )  => '',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'        => '',
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 1500px )", 'rion' ),
							"param_name"  => "ls_items",
							"value"       => "3",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 1200px < 1500px )", 'rion' ),
							"param_name"  => "lg_items",
							"value"       => "3",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 992px < 1200px )", 'rion' ),
							"param_name"  => "md_items",
							"value"       => "3",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on tablet (Screen resolution of device >=768px and < 992px )", 'rion' ),
							"param_name"  => "sm_items",
							"value"       => "2",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on mobile landscape(Screen resolution of device >=480px and < 768px)", 'rion' ),
							"param_name"  => "xs_items",
							"value"       => "2",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on mobile (Screen resolution of device < 480px)", 'rion' ),
							"param_name"  => "ts_items",
							"value"       => "1",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'blog_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			/*Section Button*/
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Button', 'rion' ),
					'base'        => 'rion_button', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display Button.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'testimonial.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select Style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'button/style-01.jpg'
								),
                                'style-02' => array(
									'alt' => 'Style 02',
									'img' => RION_SHORTCODE_PREVIEW . 'button/style-02.jpg'
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'        => 'vc_link',
							'heading'     => esc_html__( 'Button Link', 'rion' ),
							'param_name'  => 'link',
							'description' => esc_html__( 'Add button link.', 'rion' ),
                            'admin_label' => true,
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Choose use icon', 'rion' ),
							'value'      => array(
								esc_html__( 'No', 'rion' ) => '',
								esc_html__( 'Yes', 'rion' )   => 'icontype',
							),
							'param_name' => 'iconimage',
							'std'        => '',
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Icon library', 'rion' ),
							'value'       => array(
								esc_html__( 'Font Awesome', 'rion' )  => 'fontawesome',
								esc_html__( 'Font Flaticon', 'rion' ) => 'fontflaticon',
							),
							'admin_label' => true,
							'param_name'  => 'i_type',
							'description' => esc_html__( 'Select icon library.', 'rion' ),
							'std'         => 'fontawesome',
							'dependency'  => array(
								'element' => 'iconimage',
								'value'   => 'icontype',
							),
						),
						array(
							'param_name'  => 'icon_rioncustomfonts',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
							'type'        => 'iconpicker',
							'settings'    => array(
								'emptyIcon' => true,
								'type'      => 'rioncustomfonts',
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontflaticon',
							),
						),
						array(
							'type'        => 'iconpicker',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'param_name'  => 'icon_fontawesome',
							'value'       => 'fa fa-adjust',
							'settings'    => array(
								'emptyIcon'    => false,
								'iconsPerPage' => 4000,
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontawesome',
							),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" )
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'button_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						)
					)
				)
			);
			vc_map(
				array(
					'base'        => 'rion_contact',
					'name'        => esc_html__( 'Rion: Contact', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'cat.png',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display Custom Contact', 'rion' ),
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'contact/style-01.jpg',
								),
                                'style-02' => array(
									'alt' => 'Style 02',
									'img' => RION_SHORTCODE_PREVIEW . 'contact/style-02.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'admin_label' => true,
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Description', 'rion' ),
							'param_name'  => 'desc',
							'admin_label' => true,
						),
						array(
							'type'       => 'param_group',
							'heading'    => esc_html__( 'Contact Items', 'rion' ),
							'param_name' => 'contact_item',
							'params'     => array(
								array(
									'type'        => 'textfield',
									'heading'     => esc_html__( 'Title Item', 'rion' ),
									'param_name'  => 'title_item',
									'admin_label' => true,
								),
								array(
									'type'       => 'vc_link',
									'heading'    => esc_html__( 'Link', 'rion' ),
									'param_name' => 'link_item',
								),
							),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'contact_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			/*Map New Custom menu*/
			$all_menu = array();
			$menus    = get_terms( 'nav_menu', array( 'hide_empty' => false ) );
			if ( $menus && count( $menus ) > 0 ) {
				foreach ( $menus as $m ) {
					$all_menu[ $m->name ] = $m->slug;
				}
			}
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Custom Menu', 'rion' ),
					'base'        => 'rion_custommenu', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a custom menu.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'custom-menu.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select Style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'custommenu/style-01.jpg',
								),
								'style-02' => array(
									'alt' => 'Style 02',
									'img' => RION_SHORTCODE_PREVIEW . 'custommenu/style-02.jpg',
								),
                                'style-03' => array(
									'alt' => 'Style 03',
									'img' => RION_SHORTCODE_PREVIEW . 'custommenu/style-03.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'description' => esc_html__( 'The title of shortcode', 'rion' ),
							'admin_label' => true,
							'std'         => '',
                            'dependency'  => array(
                                'element' => 'style',
                                'value'   => array( 'style-01','style-03'),
                            ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Menu', 'rion' ),
							'param_name'  => 'menu',
							'value'       => $all_menu,
							'description' => esc_html__( 'Select menu to display.', 'rion' ),
                            'admin_label' => true,
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'custommenu_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Demo', 'rion' ),
					'base'        => 'rion_demo', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a demo list.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'banner.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'demo/style-01.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							"type"        => "attach_image",
							"heading"     => esc_html__( "Image", "rion" ),
							"param_name"  => "image",
							"admin_label" => false,
						),
						array(
							'type'        => 'number',
							'heading'     => esc_html__( 'Number', 'rion' ),
							'param_name'  => 'post_id',
							'description' => esc_html__( 'The Post, page id.', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array('style-02'),
							),
						),
						array(
							'type'        => 'vc_link',
							'heading'     => esc_html__( 'Demo Link', 'rion' ),
							'param_name'  => 'link',
							'description' => esc_html__( 'Add demo link.', 'rion' ),
							'admin_label' => true,
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array('style-01'),
							),
						),
                        array(
                            'type'       => 'dropdown',
                            'heading'    => esc_html__( 'Comming soon mode', 'rion' ),
                            'value'      => array(
                                esc_html__( 'Off', 'rion' )  => '',
                                esc_html__( 'On', 'rion' ) => 'comming-mode',
                            ),
                            'param_name' => 'comming',
                            'std'        => '',
                            'dependency'  => array(
                                'element' => 'style',
                                'value'   => array( 'style-01'),
                            ),
                        ),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'demo_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			/*Section IconBox*/
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Icon Box', 'rion' ),
					'base'        => 'rion_iconbox', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display Iconbox.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'iconbox.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Layout', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'iconbox/style-01.jpg'
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Choose icon or image', 'rion' ),
							'value'      => array(
								esc_html__( 'Icon', 'rion' )  => '',
								esc_html__( 'Image', 'rion' ) => 'imagetype',
							),
							'param_name' => 'iconimage',
							'std'        => '',
						),
						array(
							"type"       => "attach_image",
							"heading"    => esc_html__( "Image custom", "rion" ),
							"param_name" => "image",
							'dependency' => array(
								'element' => 'iconimage',
								'value'   => 'imagetype',
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Icon library', 'rion' ),
							'value'       => array(
								esc_html__( 'Font Awesome', 'rion' )  => 'fontawesome',
								esc_html__( 'Font Flaticon', 'rion' ) => 'fontflaticon',
							),
							'admin_label' => true,
							'param_name'  => 'i_type',
							'description' => esc_html__( 'Select icon library.', 'rion' ),
							'std'         => 'fontawesome',
							'dependency'  => array(
								'element' => 'iconimage',
								'value'   => array( '' ),
							),
						),
						array(
							'param_name'  => 'icon_rioncustomfonts',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
							'type'        => 'iconpicker',
							'settings'    => array(
								'emptyIcon' => true,
								'type'      => 'rioncustomfonts',
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontflaticon',
							),
						),
						array(
							'type'        => 'iconpicker',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'param_name'  => 'icon_fontawesome',
							'value'       => 'fa fa-adjust',
							'settings'    => array(
								'emptyIcon'    => false,
								'iconsPerPage' => 4000,
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontawesome',
							),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'description' => esc_html__( 'The Title of IconBox.', 'rion' ),
							'admin_label' => true,
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Description', 'rion' ),
							'param_name'  => 'des',
							'description' => esc_html__( 'The Description of IconBox.', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-99'),
							),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", 'rion' ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'iconbox_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),

					)
				)
			);
			/* Map New Section tabs */
			vc_map(
				array(
					'name'                      => esc_html__( 'Section', 'rion' ),
					'base'                      => 'vc_tta_section',
					'icon'                      => 'icon-wpb-ui-tta-section',
					'allowed_container_element' => 'vc_row',
					'is_container'              => true,
					'show_settings_on_create'   => false,
					'as_child'                  => array(
						'only' => 'vc_tta_tour,vc_tta_tabs,vc_tta_accordion',
					),
					'category'                  => esc_html__( 'Content', 'rion' ),
					'description'               => esc_html__( 'Section for Tabs, Tours, Accordions.', 'rion' ),
					'params'                    => array(
                        array(
                            'type'        => 'textfield',
                            'param_name'  => 'title',
                            'heading'     => esc_html__( 'Title', 'rion' ),
                            'description' => esc_html__( 'Enter section title (Note: you can leave it empty).', 'rion' ),
                        ),
                        array(
                            'type'        => 'attach_image',
                            'param_name'  => 'image',
                            'heading'     => esc_html__( 'Image', 'rion' ),
                            'description' => esc_html__( 'Enter section image.', 'rion' ),
                        ),
						array(
							'type'        => 'el_id',
							'param_name'  => 'tab_id',
							'settings'    => array(
								'auto_generate' => true,
							),
							'heading'     => esc_html__( 'Section ID', 'rion' ),
							'description' => esc_html__( 'Enter section ID (Note: make sure it is unique and valid according to w3c specification.', 'rion' )
						),
						array(
							'type'        => 'checkbox',
							'param_name'  => 'add_icon',
							'heading'     => esc_html__( 'Add icon?', 'rion' ),
							'description' => esc_html__( 'Add icon next to section title.', 'rion' ),
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'i_position',
							'value'       => array(
								esc_html__( 'Before title', 'rion' ) => 'left',
								esc_html__( 'After title', 'rion' )  => 'right',
							),
							'dependency'  => array(
								'element' => 'add_icon',
								'value'   => 'true',
							),
							'heading'     => esc_html__( 'Icon position', 'rion' ),
							'description' => esc_html__( 'Select icon position.', 'rion' ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Icon library', 'rion' ),
							'value'       => array(
								esc_html__( 'Font Awesome', 'rion' )  => 'fontawesome',
								esc_html__( 'Font Flaticon', 'rion' ) => 'fontflaticon',
							),
							'dependency'  => array(
								'element' => 'add_icon',
								'value'   => 'true',
							),
							'admin_label' => true,
							'param_name'  => 'i_type',
							'std'         => 'fontawesome',
							'description' => esc_html__( 'Select icon library.', 'rion' ),
						),
						array(
							'param_name'  => 'icon_rioncustomfonts',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
							'type'        => 'iconpicker',
							'settings'    => array(
								'emptyIcon' => true,
								'type'      => 'rioncustomfonts',
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontflaticon',
							),
						),
						array(
							'type'        => 'iconpicker',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'param_name'  => 'icon_fontawesome',
							'value'       => 'fa fa-adjust',
							// default value to backend editor admin_label
							'settings'    => array(
								'emptyIcon'    => false,
								// default true, display an "EMPTY" icon?
								'iconsPerPage' => 4000,
								// default 100, how many icons per/page to display, we use (big number) to display all icons in single page
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontawesome',
							),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Extra class name', 'rion' ),
							'param_name'  => 'el_class',
							'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'rion' ),
						),
					),
					'js_view'                   => 'VcBackendTtaSectionView',
					'custom_markup'             => '
                    <div class="vc_tta-panel-heading">
                        <h4 class="vc_tta-panel-title vc_tta-controls-icon-position-left"><a href="javascript:;" data-vc-target="[data-model-id=\'{{ model_id }}\']" data-vc-accordion data-vc-container=".vc_tta-container"><span class="vc_tta-title-text">{{ section_title }}</span><i class="vc_tta-controls-icon vc_tta-controls-icon-plus"></i></a></h4>
                    </div>
                    <div class="vc_tta-panel-body">
                        {{ editor_controls }}
                        <div class="{{ container-class }}">
                        {{ content }}
                        </div>
                    </div>',
					'default_content'           => '',
				)
			);

			/*Map New section title */
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Section Title', 'rion' ),
					'base'        => 'rion_title',
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a custom title.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'section-title.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'title/style-01.jpg',
								),
                                'style-02' => array(
									'alt' => 'Style 02', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'title/style-02.jpg',
								),
                                'style-03' => array(
									'alt' => 'Style 03', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'title/style-03.jpg',
								),
                                'style-04' => array(
									'alt' => 'Style 04', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'title/style-04.jpg',
								),
                                'style-05' => array(
									'alt' => 'Style 05', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'title/style-05.jpg',
								),
                                'style-06' => array(
									'alt' => 'Style 06', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'title/style-06.jpg',
								),
                                'style-07' => array(
									'alt' => 'Style 07', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'title/style-07.jpg',
								),
                                'style-08' => array(
									'alt' => 'Style 08', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'title/style-08.jpg',
								),
                                'style-09' => array(
									'alt' => 'Style 09', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'title/style-09.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'description' => esc_html__( 'The title of shortcode', 'rion' ),
							'admin_label' => true,
							'std'         => '',
						),
                        array(
                            'type'        => 'textfield',
                            'heading'     => esc_html__( 'Description', 'rion' ),
                            'param_name'  => 'desc',
                            'description' => esc_html__( 'The description of shortcode', 'rion' ),
                            'std'         => '',
                            'dependency'  => array(
	                            'element' => 'style',
	                            'value'   => array('style-01','style-02','style-03','style-06'),
                            ),
                        ),
						array(
							'type'       => 'vc_link',
							'heading'    => esc_html__( 'Link', 'rion' ),
							'param_name' => 'link',
							'dependency'  => array(
								'element' => 'style',
								'value'   => array('style-01','style-02','style-03','style-06','style-07'),
							),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'title_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			// Map new Tabs element.
			vc_map(
				array(
					'name'                    => esc_html__( 'Rion: Tabs', 'rion' ),
					'base'                    => 'rion_tabs',
					'icon'                    => RION_SHORTCODES_ICONS_URI . 'tabs.png',
					'is_container'            => true,
					'show_settings_on_create' => false,
					'as_parent'               => array(
						'only' => 'vc_tta_section',
					),
					'category'                => esc_html__( 'Rion Elements', 'rion' ),
					'description'             => esc_html__( 'Tabs content', 'rion' ),
					'params'                  => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'tabs/style-01.jpg',
								),
                                'style-02' => array(
									'alt' => 'Style 02', //RION_SHORTCODE_PREVIEW
									'img' => RION_SHORTCODE_PREVIEW . 'tabs/style-02.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
                        array(
                            'type'        => 'textfield',
                            'heading'     => esc_html__( 'Title', 'rion' ),
                            'param_name'  => 'title_tabs',
                            'description' => esc_html__( 'The title of shortcode', 'rion' ),
                            'admin_label' => true,
                            'std'         => '',
                        ),
                        array(
                            'type'       => 'vc_link',
                            'heading'    => esc_html__( 'Link', 'rion' ),
                            'param_name' => 'link',
                            'dependency'  => array(
                                'element' => 'style',
                                'value'   => array('style-99'),
                            ),
                        ),
						vc_map_add_css_animation(),
						array(
							'param_name' => 'ajax_check',
							'heading'    => esc_html__( 'Using Ajax Tabs', 'rion' ),
							'type'       => 'dropdown',
							'value'      => array(
								esc_html__( 'Yes', 'rion' ) => '1',
								esc_html__( 'No', 'rion' )  => '0',
							),
							'std'        => '0',
						),
						array(
							'type'       => 'textfield',
							'heading'    => esc_html__( 'Active Section', 'rion' ),
							'param_name' => 'active_section',
							'std'        => '1',
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Extra class name', 'rion' ),
							'param_name'  => 'el_class',
							'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'rion' ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'CSS box', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'tabs_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
						array(
							'type'             => 'checkbox',
							'param_name'       => 'collapsible_all',
							'heading'          => esc_html__( 'Allow collapse all?', 'rion' ),
							'description'      => esc_html__( 'Allow collapse all accordion sections.', 'rion' ),
							'edit_field_class' => 'hidden',
						),
					),
					'js_view'                 => 'VcBackendTtaTabsView',
					'custom_markup'           => '
                    <div class="vc_tta-container" data-vc-action="collapse">
                        <div class="vc_general vc_tta vc_tta-tabs vc_tta-color-backend-tabs-white vc_tta-style-flat vc_tta-shape-rounded vc_tta-spacing-1 vc_tta-tabs-position-top vc_tta-controls-align-left">
                            <div class="vc_tta-tabs-container">'
					                             . '<ul class="vc_tta-tabs-list">'
					                             . '<li class="vc_tta-tab" data-vc-tab data-vc-target-model-id="{{ model_id }}" data-element_type="vc_tta_section"><a href="javascript:;" data-vc-tabs data-vc-container=".vc_tta" data-vc-target="[data-model-id=\'{{ model_id }}\']" data-vc-target-model-id="{{ model_id }}"><span class="vc_tta-title-text">{{ section_title }}</span></a></li>'
					                             . '</ul>
                            </div>
                            <div class="vc_tta-panels vc_clearfix {{container-class}}">
                              {{ content }}
                            </div>
                        </div>
                    </div>',
					'default_content'         => '
                        [vc_tta_section title="' . sprintf( '%s %d', esc_html__( 'Tab', 'rion' ), 1 ) . '"][/vc_tta_section]
                        [vc_tta_section title="' . sprintf( '%s %d', esc_html__( 'Tab', 'rion' ), 2 ) . '"][/vc_tta_section]
                    ',
					'admin_enqueue_js'        => array(
						vc_asset_url( 'lib/vc_tabs/vc-tabs.min.js' ),
					),
				)
			);
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Video', 'rion' ),
					'base'        => 'rion_video', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display shortcode.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'testimonial.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select Style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'video/style-01.jpg'
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Video Type', 'rion' ),
							'value'       => array(
								esc_html__( 'Video html5', 'rion' )  => 'html5',
								esc_html__( 'Vimeo', 'rion' )        => 'vimeo',
								esc_html__( 'Youtube', 'rion' )      => 'youtbe',
							),
							'param_name'  => 'type',
							'std'         => 'html5',
							'description' => esc_html__( 'Select video type.', 'rion' ),
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Video ID', 'rion' ),
							'param_name'  => 'video',
							'description' => esc_html__( 'Add video id.', 'rion' ),
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Video Loop', 'rion' ),
							'value'       => array(
								esc_html__( 'Yes', 'rion' )  => 'yes',
								esc_html__( 'No', 'rion' )   => 'no',
							),
							'param_name'  => 'loop',
							'std'         => 'yes',
							'description' => esc_html__( 'Select video loop.', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Video Autoplay', 'rion' ),
							'value'       => array(
								esc_html__( 'Yes', 'rion' )  => 'yes',
								esc_html__( 'No', 'rion' )   => 'no',
							),
							'param_name'  => 'autoplay',
							'std'         => 'yes',
							'description' => esc_html__( 'Select video autoplay.', 'rion' ),
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01'),
							),
						),
						array(
							'type'        => 'attach_image',
							'param_name'  => 'image',
							'heading'     => esc_html__( 'Background Image', 'rion' ),
							'description' => esc_html__( 'Enter section image.', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-02','style-03'),
							),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'description' => esc_html__( 'The Title', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-03'),
							),
						),
						array(
							'type'        => 'vc_link',
							'heading'     => esc_html__( 'Button Link', 'rion' ),
							'param_name'  => 'link',
							'description' => esc_html__( 'Add button link.', 'rion' ),
							'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-02','style-03'),
							),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" )
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'video_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						)
					)
				)
			);
			// Map new Products
			// CUSTOM PRODUCT SIZE
			$product_size_width_list = array();
			$width                   = 330;
			$height                  = 348;
			$crop                    = 1;
            if ( function_exists( 'wc_get_image_size' ) ) {
	            $size      = array(
		            "width"  => 330,
		            "height" => 348,
		            "crop"   => 1,
	            );
                $width  = isset( $size['width'] ) && is_numeric($size['width']) ? $size['width'] : $width;
                $height = isset( $size['height']) && is_numeric($size['height']) ? $size['height'] : $height;
                $crop   = isset( $size['crop'] ) ? $size['crop'] : $crop;
            }
			for ( $i = 100; $i < $width; $i = $i + 10 ) {
				array_push( $product_size_width_list, $i );
			}
			$product_size_list                           = array();
			$product_size_list[ $width . 'x' . $height ] = $width . 'x' . $height;
			foreach ( $product_size_width_list as $k => $w ) {
			    if(is_numeric($w)) {
                    $w = intval( $w );
                    if ( isset( $width ) && $width > 0 ) {
                        $h = round( $height * $w / $width );
                    } else {
                        $h = $w;
                    }
                    $product_size_list[ $w . 'x' . $h ] = $w . 'x' . $h;
                }
			}
			$product_size_list['Custom'] = 'custom';
			$attributes_tax              = array();
			if ( function_exists( 'wc_get_attribute_taxonomies' ) ) {
				$attributes_tax = wc_get_attribute_taxonomies();
			}

			$attributes = array();
			if ( is_array( $attributes_tax ) && count( $attributes_tax ) > 0 ) {
				foreach ( $attributes_tax as $attribute ) {
					$attributes[ $attribute->attribute_label ] = $attribute->attribute_name;
				}
			}
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Products', 'rion' ),
					'base'        => 'rion_products', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a product list or grid.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'product.png',
					'params'      => array(
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Product List style', 'rion' ),
							'param_name'  => 'productsliststyle',
							'value'       => array(
								esc_html__( 'Grid Bootstrap', 'rion' ) => 'grid',
								esc_html__( 'Owl Carousel', 'rion' )   => 'owl',
							),
							'description' => esc_html__( 'Select a style for list', 'rion' ),
							'admin_label' => true,
							'std'         => 'grid',
						),
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Product style', 'rion' ),
							'value'       => array(
								'1' => array(
									'alt' => esc_html__( 'Style 01', 'rion' ),
									'img' => RION_PRODUCT_STYLE_PREVIEW . 'content-product-style-1.jpg',
								),
                                '2' => array(
									'alt' => esc_html__( 'Style 02', 'rion' ),
									'img' => RION_PRODUCT_STYLE_PREVIEW . 'content-product-style-2.jpg',
								),
							),
							'default'     => '1',
							'admin_label' => true,
							'param_name'  => 'product_style',
							'description' => esc_html__( 'Select a style for product item', 'rion' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'description' => esc_html__( 'The title of shortcode', 'rion' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Drag text', 'rion' ),
							'param_name'  => 'drag',
							'description' => esc_html__( 'The drag text of shortcode', 'rion' ),
							'dependency'  => array(
								'element' => 'productsliststyle',
								'value'   => array('owl')
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Show Star Rating', 'rion' ),
							'param_name'  => 'show_star',
							'value'       => array(
								esc_html__( 'Show Rating', 'rion' ) => '',
								esc_html__( 'None Rating', 'rion' )   => 'no-star',
							),
							'description' => esc_html__( 'Select show star rating', 'rion' ),
							'std'         => '',
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Show New Label', 'rion' ),
							'param_name'  => 'show_new',
							'value'       => array(
								esc_html__( 'Show New Label', 'rion' ) => '',
								esc_html__( 'None New Label', 'rion' )   => 'no-new',
							),
							'description' => esc_html__( 'Select show star rating', 'rion' ),
							'std'         => '',
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Image size', 'rion' ),
							'param_name'  => 'product_image_size',
							'value'       => $product_size_list,
							'description' => esc_html__( 'Select a size for product', 'rion' ),
							'std'         => '320x387',
							'admin_label' => true,
						),
						array(
							"type"       => "textfield",
							"heading"    => esc_html__( "Width", 'rion' ),
							"param_name" => "product_custom_thumb_width",
							"value"      => $width,
							"suffix"     => esc_html__( "px", 'rion' ),
							"dependency" => array( "element" => "product_image_size", "value" => array( 'custom' ) ),
						),
						array(
							"type"       => "textfield",
							"heading"    => esc_html__( "Height", 'rion' ),
							"param_name" => "product_custom_thumb_height",
							"value"      => $height,
							"suffix"     => esc_html__( "px", 'rion' ),
							"dependency" => array( "element" => "product_image_size", "value" => array( 'custom' ) ),
						),
						/*Products */
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Target', 'rion' ),
							'param_name'  => 'target',
							'value'       => array(
								esc_html__( 'Best Selling Products', 'rion' ) => 'best-selling',
								esc_html__( 'Top Rated Products', 'rion' )    => 'top-rated',
								esc_html__( 'Recent Products', 'rion' )       => 'recent-product',
								esc_html__( 'Product Category', 'rion' )      => 'product-category',
								esc_html__( 'Products', 'rion' )              => 'products',
								esc_html__( 'Featured Products', 'rion' )     => 'featured_products',
								esc_html__( 'On Sale', 'rion' )               => 'on_sale',
								esc_html__( 'On New', 'rion' )                => 'on_new',
							),
							'description' => esc_html__( 'Choose the target to filter products', 'rion' ),
							'std'         => 'recent-product',
							'group'       => esc_html__( 'Products options', 'rion' ),
						),
                        array(
                            "type"        => "taxonomy",
                            "taxonomy"    => "product_cat",
                            "class"       => "",
                            "heading"     => esc_html__( "Product Category", 'rion' ),
                            "param_name"  => "taxonomy",
                            "value"       => '',
                            'parent'      => '',
                            'multiple'    => true,
                            'hide_empty'  => false,
                            'placeholder' => esc_html__( 'Choose category', 'rion' ),
                            "description" => esc_html__( "Note: If you want to narrow output, select category(s) above. Only selected categories will be displayed.", 'rion' ),
                            'std'         => '',
                            'group'       => esc_html__( 'Products options', 'rion' ),
                        ),
                        array(
                            'type'       => 'textfield',
                            'heading'    => esc_html__( 'Total items', 'rion' ),
                            'param_name' => 'per_page',
                            'value'      => 10,
                            "dependency" => array(
                                "element" => "target",
                                "value"   => array(
                                    'best-selling',
                                    'top-rated',
                                    'recent-product',
                                    'product-category',
                                    'featured_products',
                                    'product_attribute',
                                    'on_sale',
                                    'on_new'
                                )
                            ),
                            'group'       => esc_html__( 'Products options', 'rion' ),
                        ),
						array(
							"type"        => "dropdown",
							"heading"     => esc_html__( "Order by", 'rion' ),
							"param_name"  => "orderby",
							"value"       => array(
								'',
								esc_html__( 'Date', 'rion' )          => 'date',
								esc_html__( 'ID', 'rion' )            => 'ID',
								esc_html__( 'Author', 'rion' )        => 'author',
								esc_html__( 'Title', 'rion' )         => 'title',
								esc_html__( 'Modified', 'rion' )      => 'modified',
								esc_html__( 'Random', 'rion' )        => 'rand',
								esc_html__( 'Comment count', 'rion' ) => 'comment_count',
								esc_html__( 'Menu order', 'rion' )    => 'menu_order',
								esc_html__( 'Sale price', 'rion' )    => '_sale_price',
							),
							'std'         => 'date',
							"description" => esc_html__( "Select how to sort.", 'rion' ),
							"dependency"  => array(
								"element" => "target",
								"value"   => array(
									'top-rated',
									'recent-product',
									'product-category',
									'featured_products',
									'on_sale',
									'on_new',
									'product_attribute'
								)
							),
							'group'       => esc_html__( 'Products options', 'rion' ),
						),
						array(
							"type"        => "dropdown",
							"heading"     => esc_html__( "Order", 'rion' ),
							"param_name"  => "order",
							"value"       => array(
								esc_html__( 'ASC', 'rion' )  => 'ASC',
								esc_html__( 'DESC', 'rion' ) => 'DESC',
							),
							'std'         => 'DESC',
							"description" => esc_html__( "Designates the ascending or descending order.", 'rion' ),
							"dependency"  => array(
								"element" => "target",
								"value"   => array(
									'top-rated',
									'recent-product',
									'product-category',
									'featured_products',
									'on_sale',
									'on_new',
									'product_attribute'
								)
							),
							'group'       => esc_html__( 'Products options', 'rion' ),
						),
						array(
							'type'        => 'autocomplete',
							'heading'     => esc_html__( 'Products', 'rion' ),
							'param_name'  => 'ids',
							'settings'    => array(
								'multiple'      => true,
								'sortable'      => true,
								'unique_values' => true,
							),
							'save_always' => true,
							'description' => esc_html__( 'Enter List of Products', 'rion' ),
							"dependency"  => array( "element" => "target", "value" => array( 'products' ) ),
							'group'       => esc_html__( 'Products options', 'rion' ),
						),
						/* OWL Settings */
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( '1 Row', 'rion' )  => '1',
								esc_html__( '2 Rows', 'rion' ) => '2',
								esc_html__( '3 Rows', 'rion' ) => '3',
								esc_html__( '4 Rows', 'rion' ) => '4',
								esc_html__( '5 Rows', 'rion' ) => '5',
							),
							'std'         => '1',
							'heading'     => esc_html__( 'The number of rows which are shown on block', 'rion' ),
							'param_name'  => 'owl_number_row',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Rows space', 'rion' ),
							'param_name' => 'owl_rows_space',
							'value'      => array(
								esc_html__( 'Default', 'rion' ) => 'rows-space-0',
								esc_html__( '10px', 'rion' )    => 'rows-space-10',
								esc_html__( '20px', 'rion' )    => 'rows-space-20',
								esc_html__( '30px', 'rion' )    => 'rows-space-30',
								esc_html__( '40px', 'rion' )    => 'rows-space-40',
								esc_html__( '50px', 'rion' )    => 'rows-space-50',
								esc_html__( '60px', 'rion' )    => 'rows-space-60',
								esc_html__( '70px', 'rion' )    => 'rows-space-70',
								esc_html__( '80px', 'rion' )    => 'rows-space-80',
								esc_html__( '90px', 'rion' )    => 'rows-space-90',
								esc_html__( '100px', 'rion' )   => 'rows-space-100',
							),
							'std'        => 'rows-space-0',
							'group'      => esc_html__( 'Carousel settings', 'rion' ),
							"dependency" => array(
								"element" => "owl_number_row",
								"value"   => array( '2', '3', '4', '5' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Yes', 'rion' ) => 'true',
								esc_html__( 'No', 'rion' )  => 'false',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'AutoPlay', 'rion' ),
							'param_name'  => 'autoplay',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'No', 'rion' )  => 'false',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'         => false,
							'heading'     => esc_html__( 'Navigation', 'rion' ),
							'param_name'  => 'navigation',
							'description' => esc_html__( "Show buton 'next' and 'prev' buttons.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
							'admin_label' => false,
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Center', 'rion' )  => '',
								esc_html__( 'Center Square', 'rion' ) => 'nav-center-square',
								esc_html__( 'Right', 'rion' ) => 'nav-right',
							),
							'std'         => '',
							'heading'     => esc_html__( 'Navigation type', 'rion' ),
							'param_name'  => 'nav_type',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							'dependency'  => array(
								'element' => 'navigation',
								'value'   => array( 'true' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'No', 'rion' )  => 'false',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'         => false,
							'heading'     => esc_html__( 'Enable Dots', 'rion' ),
							'param_name'  => 'dots',
							'description' => esc_html__( "Show buton dots", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
							'admin_label' => false,
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Default', 'rion' )  => '',
								esc_html__( 'Light', 'rion' ) => 'dots-light',
								esc_html__( 'Dark', 'rion' ) => 'dots-dark',
							),
							'std'         => '',
							'heading'     => esc_html__( 'Dots color', 'rion' ),
							'param_name'  => 'dots_color',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							'dependency'  => array(
								'element' => 'dots',
								'value'   => array( 'true' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
                                esc_html__( 'No', 'rion' )  => 'false',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'         => false,
							'heading'     => esc_html__( 'Loop', 'rion' ),
							'param_name'  => 'loop',
							'description' => esc_html__( "Inifnity loop. Duplicate last and first items to get loop illusion.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Slide Speed", 'rion' ),
							"param_name"  => "slidespeed",
							"value"       => "200",
							"suffix"      => esc_html__( "milliseconds", 'rion' ),
							"description" => esc_html__( 'Slide speed in milliseconds', 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Margin", 'rion' ),
							"param_name"  => "margin",
							"value"       => "0",
							"description" => esc_html__( 'Distance( or space) between 2 item', 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Auto Responsive Margin', 'rion' ),
							'param_name' => 'autoresponsive',
							'group'      => esc_html__( 'Carousel settings', 'rion' ),
							'value'      => array(
								esc_html__( 'No', 'rion' )  => '',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'        => '',
							"dependency" => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 1500px )", 'rion' ),
							"param_name"  => "ls_items",
							"value"       => "5",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 1200px and < 1500px )", 'rion' ),
							"param_name"  => "lg_items",
							"value"       => "4",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 992px < 1200px )", 'rion' ),
							"param_name"  => "md_items",
							"value"       => "3",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on tablet (Screen resolution of device >=768px and < 992px )", 'rion' ),
							"param_name"  => "sm_items",
							"value"       => "3",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on mobile landscape(Screen resolution of device >=480px and < 768px)", 'rion' ),
							"param_name"  => "xs_items",
							"value"       => "2",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on mobile (Screen resolution of device < 480px)", 'rion' ),
							"param_name"  => "ts_items",
							"value"       => "2",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'owl' ),
							),
						),
						/* Bostrap setting */
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Rows space', 'rion' ),
							'param_name' => 'boostrap_rows_space',
							'value'      => array(
								esc_html__( 'Default', 'rion' ) => 'rows-space-0',
								esc_html__( '10px', 'rion' )    => 'rows-space-10',
								esc_html__( '20px', 'rion' )    => 'rows-space-20',
								esc_html__( '30px', 'rion' )    => 'rows-space-30',
								esc_html__( '40px', 'rion' )    => 'rows-space-40',
								esc_html__( '50px', 'rion' )    => 'rows-space-50',
								esc_html__( '60px', 'rion' )    => 'rows-space-60',
								esc_html__( '70px', 'rion' )    => 'rows-space-70',
								esc_html__( '80px', 'rion' )    => 'rows-space-80',
								esc_html__( '90px', 'rion' )    => 'rows-space-90',
								esc_html__( '100px', 'rion' )   => 'rows-space-100',
							),
							'std'        => 'rows-space-0',
							'group'      => esc_html__( 'Boostrap settings', 'rion' ),
							"dependency" => array(
								"element" => "productsliststyle",
								"value"   => array( 'grid' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Items per row on Desktop', 'rion' ),
							'param_name'  => 'boostrap_bg_items',
							'value'       => array(
								esc_html__( '1 item', 'rion' )  => '12',
								esc_html__( '2 items', 'rion' ) => '6',
								esc_html__( '3 items', 'rion' ) => '4',
								esc_html__( '4 items', 'rion' ) => '3',
								esc_html__( '5 items', 'rion' ) => '15',
								esc_html__( '6 items', 'rion' ) => '2',
							),
							'description' => esc_html__( '(Item per row on screen resolution of device >= 1500px )', 'rion' ),
							'group'       => esc_html__( 'Boostrap settings', 'rion' ),
							'std'         => '15',
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'grid' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Items per row on Desktop', 'rion' ),
							'param_name'  => 'boostrap_lg_items',
							'value'       => array(
								esc_html__( '1 item', 'rion' )  => '12',
								esc_html__( '2 items', 'rion' ) => '6',
								esc_html__( '3 items', 'rion' ) => '4',
								esc_html__( '4 items', 'rion' ) => '3',
								esc_html__( '5 items', 'rion' ) => '15',
								esc_html__( '6 items', 'rion' ) => '2',
							),
							'description' => esc_html__( '(Item per row on screen resolution of device >= 1200px and < 1500px )', 'rion' ),
							'group'       => esc_html__( 'Boostrap settings', 'rion' ),
							'std'         => '3',
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'grid' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Items per row on landscape tablet', 'rion' ),
							'param_name'  => 'boostrap_md_items',
							'value'       => array(
								esc_html__( '1 item', 'rion' )  => '12',
								esc_html__( '2 items', 'rion' ) => '6',
								esc_html__( '3 items', 'rion' ) => '4',
								esc_html__( '4 items', 'rion' ) => '3',
								esc_html__( '5 items', 'rion' ) => '15',
								esc_html__( '6 items', 'rion' ) => '2',
							),
							'description' => esc_html__( '(Item per row on screen resolution of device >=992px and < 1200px )', 'rion' ),
							'group'       => esc_html__( 'Boostrap settings', 'rion' ),
							'std'         => '3',
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'grid' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Items per row on portrait tablet', 'rion' ),
							'param_name'  => 'boostrap_sm_items',
							'value'       => array(
								esc_html__( '1 item', 'rion' )  => '12',
								esc_html__( '2 items', 'rion' ) => '6',
								esc_html__( '3 items', 'rion' ) => '4',
								esc_html__( '4 items', 'rion' ) => '3',
								esc_html__( '5 items', 'rion' ) => '15',
								esc_html__( '6 items', 'rion' ) => '2',
							),
							'description' => esc_html__( '(Item per row on screen resolution of device >=768px and < 992px )', 'rion' ),
							'group'       => esc_html__( 'Boostrap settings', 'rion' ),
							'std'         => '4',
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'grid' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Items per row on Mobile', 'rion' ),
							'param_name'  => 'boostrap_xs_items',
							'value'       => array(
								esc_html__( '1 item', 'rion' )  => '12',
								esc_html__( '2 items', 'rion' ) => '6',
								esc_html__( '3 items', 'rion' ) => '4',
								esc_html__( '4 items', 'rion' ) => '3',
								esc_html__( '5 items', 'rion' ) => '15',
								esc_html__( '6 items', 'rion' ) => '2',
							),
							'description' => esc_html__( '(Item per row on screen resolution of device >=480  add < 768px )', 'rion' ),
							'group'       => esc_html__( 'Boostrap settings', 'rion' ),
							'std'         => '6',
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'grid' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Items per row on Mobile', 'rion' ),
							'param_name'  => 'boostrap_ts_items',
							'value'       => array(
								esc_html__( '1 item', 'rion' )  => '12',
								esc_html__( '2 items', 'rion' ) => '6',
								esc_html__( '3 items', 'rion' ) => '4',
								esc_html__( '4 items', 'rion' ) => '3',
								esc_html__( '5 items', 'rion' ) => '15',
								esc_html__( '6 items', 'rion' ) => '2',
							),
							'description' => esc_html__( '(Item per row on screen resolution of device < 480px)', 'rion' ),
							'group'       => esc_html__( 'Boostrap settings', 'rion' ),
							'std'         => '12',
							"dependency"  => array(
								"element" => "productsliststyle",
								"value"   => array( 'grid' ),
							),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'products_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			/* Instagram */
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Instagram Feed', 'rion' ),
					'base'        => 'rion_instagram', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a instagram photo list.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'instagram.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'instagram/style-01.jpg',
								),
                                'style-02' => array(
									'alt' => 'Style 02',
									'img' => RION_SHORTCODE_PREVIEW . 'instagram/style-02.jpg',
								),
                                'style-03' => array(
									'alt' => 'Style 03',
									'img' => RION_SHORTCODE_PREVIEW . 'instagram/style-03.jpg',
								),
                                'style-04' => array(
									'alt' => 'Style 04',
									'img' => RION_SHORTCODE_PREVIEW . 'instagram/style-04.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Choose icon or image', 'rion' ),
							'value'      => array(
								esc_html__( 'No use', 'rion' ) => '',
								esc_html__( 'Icon', 'rion' )   => 'icontype',
								esc_html__( 'Image', 'rion' )  => 'imagetype',
							),
							'param_name' => 'iconimage',
							'std'        => '',
                            'dependency'=> array(
								'element' => 'style',
								'value'   => array( 'style-01','style-03' ),
							),
						),
						array(
							"type"       => "attach_image",
							"heading"    => esc_html__( "Image custom", "rion" ),
							"param_name" => "image",
							'dependency' => array(
								'element' => 'iconimage',
								'value'   => 'imagetype',
							),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Icon library', 'rion' ),
							'value'       => array(
								esc_html__( 'Font Awesome', 'rion' )  => 'fontawesome',
								esc_html__( 'Font Flaticon', 'rion' ) => 'fontflaticon',
							),
							'admin_label' => true,
							'param_name'  => 'i_type',
							'description' => esc_html__( 'Select icon library.', 'rion' ),
							'std'         => 'fontawesome',
							'dependency'  => array(
								'element' => 'iconimage',
								'value'   => 'icontype',
							),
						),
						array(
							'param_name'  => 'icon_rioncustomfonts',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
							'type'        => 'iconpicker',
							'settings'    => array(
								'emptyIcon' => true,
								'type'      => 'rioncustomfonts',
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontflaticon',
							),
						),
						array(
							'type'        => 'iconpicker',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'param_name'  => 'icon_fontawesome',
							'value'       => 'fa fa-adjust',
							'settings'    => array(
								'emptyIcon'    => false,
								'iconsPerPage' => 4000,
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontawesome',
							),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'description' => esc_html__( 'The title of shortcode', 'rion' ),
							'std'         => '',
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array('style-01','style-02','style-04'),
							),
						),
						array(
							'type'        => 'textarea_html',
							'heading'     => esc_html__( 'Description', 'rion' ),
							'param_name'  => 'content',
							'description' => esc_html__( 'The description of shortcode', 'rion' ),
							'std'         => '',
							'dependency'  => array(
								'element' => 'style',
								'value'   => array('style-01','style-03'),
							),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Images limit', 'rion' ),
							'param_name'  => 'limit',
							'std'         => '6',
							'admin_label' => true,
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Instagram user ID', 'rion' ),
							'param_name'  => 'id',
							'admin_label' => true,
							'description' => esc_html__( 'Your Instagram ID. Ex: 2267639447. ', 'rion' ) . '<a href="http://instagram.pixelunion.net/" target="_blank">' . esc_html__( 'How to find?', 'rion' ) . '</a>',
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Access token', 'rion' ),
							'param_name'  => 'token',
							'description' => esc_html__( 'Your Instagram token. Ex: 2267639447.1677ed0.eade9f2bbe8245ea8bdedab984f3b4c3. ', 'rion' ) . '<a href="http://instagram.pixelunion.net/" target="_blank">' . esc_html__( 'How to find?', 'rion' ) . '</a>',
							'admin_label' => true,
						),
						/* Owl */
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( '1 Row', 'rion' )  => '1',
								esc_html__( '2 Rows', 'rion' ) => '2',
								esc_html__( '3 Rows', 'rion' ) => '3',
								esc_html__( '4 Rows', 'rion' ) => '4',
								esc_html__( '5 Rows', 'rion' ) => '5',
							),
							'std'         => '1',
							'heading'     => esc_html__( 'The number of rows which are shown on block', 'rion' ),
							'param_name'  => 'owl_number_row',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Rows space', 'rion' ),
							'param_name' => 'owl_rows_space',
							'value'      => array(
								esc_html__( 'Default', 'rion' ) => 'rows-space-0',
								esc_html__( '10px', 'rion' )    => 'rows-space-10',
								esc_html__( '20px', 'rion' )    => 'rows-space-20',
								esc_html__( '30px', 'rion' )    => 'rows-space-30',
								esc_html__( '40px', 'rion' )    => 'rows-space-40',
								esc_html__( '50px', 'rion' )    => 'rows-space-50',
								esc_html__( '60px', 'rion' )    => 'rows-space-60',
								esc_html__( '70px', 'rion' )    => 'rows-space-70',
								esc_html__( '80px', 'rion' )    => 'rows-space-80',
								esc_html__( '90px', 'rion' )    => 'rows-space-90',
								esc_html__( '100px', 'rion' )   => 'rows-space-100',
							),
							'std'        => 'rows-space-0',
							'group'      => esc_html__( 'Carousel settings', 'rion' ),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Yes', 'rion' ) => 'true',
								esc_html__( 'No', 'rion' )  => 'false'
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'AutoPlay', 'rion' ),
							'param_name'  => 'autoplay',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'No', 'rion' )  => 'false',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Navigation', 'rion' ),
							'param_name'  => 'navigation',
							'description' => esc_html__( "Show buton 'next' and 'prev' buttons.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'No', 'rion' )  => 'false',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Enable Dots', 'rion' ),
							'param_name'  => 'dots',
							'description' => esc_html__( "Show buton dots.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Yes', 'rion' ) => 'true',
								esc_html__( 'No', 'rion' )  => 'false'
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Loop', 'rion' ),
							'param_name'  => 'loop',
							'description' => esc_html__( "Inifnity loop. Duplicate last and first items to get loop illusion.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Slide Speed", 'rion' ),
							"param_name"  => "slidespeed",
							"value"       => "200",
							"description" => esc_html__( 'Slide speed in milliseconds', 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Margin", 'rion' ),
							"param_name"  => "margin",
							"value"       => "30",
							"description" => esc_html__( 'Distance( or space) between 2 item', 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Auto Responsive Margin', 'rion' ),
							'param_name' => 'autoresponsive',
							'group'      => esc_html__( 'Carousel settings', 'rion' ),
							'value'      => array(
								esc_html__( 'No', 'rion' )  => '',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'        => '',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 1500px )", 'rion' ),
							"param_name"  => "ls_items",
							"value"       => "5",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 1200px )", 'rion' ),
							"param_name"  => "lg_items",
							"value"       => "4",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 992px < 1200px )", 'rion' ),
							"param_name"  => "md_items",
							"value"       => "3",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on tablet (Screen resolution of device >=768px and < 992px )", 'rion' ),
							"param_name"  => "sm_items",
							"value"       => "2",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on mobile landscape(Screen resolution of device >=480px and < 768px)", 'rion' ),
							"param_name"  => "xs_items",
							"value"       => "2",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on mobile (Screen resolution of device < 480px)", 'rion' ),
							"param_name"  => "ts_items",
							"value"       => "1",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" )
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'instagram_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						)
					)
				)
			);
			/*Map New Instagram Shop Wrap*/
			vc_map(
				array(
					'name'                    => esc_html__( 'Rion: Instagram Shop Wrap', 'rion' ),
					'base'                    => 'rion_instagramshopwrap',
					'category'                => esc_html__( 'Rion Elements', 'rion' ),
					'description'             => esc_html__( 'Display a custom instagram shop wrap.', 'rion' ),
					'as_parent'               => array( 'only' => 'ziss' ),
					'content_element'         => true,
					'show_settings_on_create' => true,
					'js_view'                 => 'VcColumnView',
					'icon'                    => RION_SHORTCODES_ICONS_URI . 'container.png',
					'params'                  => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select Style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'instagramshopwrap/style-01.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'admin_label' => true,
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Description', 'rion' ),
							'param_name'  => 'desc',
							'admin_label' => true,
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							'heading'     => esc_html__( 'Extra Class Name', 'rion' ),
							'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'rion' ),
							'type'        => 'textfield',
							'param_name'  => 'el_class',
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'instagramshopwrap_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			/*Map new Container */
			vc_map(
				array(
					'name'                    => esc_html__( 'Rion: Container', 'rion' ),
					'base'                    => 'rion_container',
					'category'                => esc_html__( 'Rion Elements', 'rion' ),
					'content_element'         => true,
					'show_settings_on_create' => true,
					'is_container'            => true,
					'js_view'                 => 'VcColumnView',
					'icon'                    => RION_SHORTCODES_ICONS_URI . 'container.png',
					'params'                  => array(
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Container Large', 'rion' ) => '',
								esc_html__( 'Container Medium', 'rion' )  => 'medium',
								esc_html__( 'Container Normal', 'rion' )  => 'normal',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Select Container', 'rion' ),
							'param_name'  => 'container_type',
							'group'       => esc_html__( 'Container settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'param_name'       => 'container_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			/*Map New Newsletter*/
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Newsletter', 'rion' ),
					'base'        => 'rion_newsletter', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a newsletter box.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'newllter.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select Style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'newsletter/style-01.jpg',
								),
                                'style-02' => array(
									'alt' => 'Style 02',
									'img' => RION_SHORTCODE_PREVIEW . 'newsletter/style-02.jpg',
								),
                                'style-03' => array(
									'alt' => 'Style 03',
									'img' => RION_SHORTCODE_PREVIEW . 'newsletter/style-03.jpg',
								),
                                'style-04' => array(
									'alt' => 'Style 04',
									'img' => RION_SHORTCODE_PREVIEW . 'newsletter/style-04.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'        => 'dropdown',
							'heading'     => esc_html__( 'Icon library', 'rion' ),
							'value'       => array(
								esc_html__( 'Font Awesome', 'rion' )  => 'fontawesome',
								esc_html__( 'Font Flaticon', 'rion' ) => 'fontflaticon',
							),
							'admin_label' => true,
							'param_name'  => 'i_type',
							'description' => esc_html__( 'Select icon library.', 'rion' ),
							'std'         => 'fontawesome',
							'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-99'),
							),
						),
						array(
							'param_name'  => 'icon_rioncustomfonts',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
							'type'        => 'iconpicker',
							'settings'    => array(
								'emptyIcon' => true,
								'type'      => 'rioncustomfonts',
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontflaticon',
							),
						),
						array(
							'type'        => 'iconpicker',
							'heading'     => esc_html__( 'Icon', 'rion' ),
							'param_name'  => 'icon_fontawesome',
							'value'       => 'fa fa-adjust',
							'settings'    => array(
								'emptyIcon'    => false,
								'iconsPerPage' => 4000,
							),
							'dependency'  => array(
								'element' => 'i_type',
								'value'   => 'fontawesome',
							),
							'description' => esc_html__( 'Select icon from library.', 'rion' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Title', 'rion' ),
							'param_name'  => 'title',
							'description' => esc_html__( 'The title of shortcode', 'rion' ),
							'admin_label' => true,
							'std'         => '',
							'dependency'  => array(
								'element' => 'style',
								'value'   => array('style-02','style-03','style-04'),
							),
						),
						array(
							'type'       => 'textarea',
							'heading'    => esc_html__( 'Description', 'rion' ),
							'param_name' => 'description',
							'std'        => '',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Placeholder text", 'rion' ),
							"param_name"  => "placeholder_text",
							"admin_label" => false,
							'std'         => 'Email address',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Placeholder text", 'rion' ),
							"param_name"  => "button_text",
							"admin_label" => false,
							'std'         => 'SUBSCRIBE',
                            'dependency'  => array(
								'element' => 'style',
								'value'   => array( 'style-01', 'style-02', 'style-04'),
							),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'newsletter_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			/*Map New Slider*/
			vc_map(
				array(
					'name'                    => esc_html__( 'Rion: Slider', 'rion' ),
					'base'                    => 'rion_slider',
					'category'                => esc_html__( 'Rion Elements', 'rion' ),
					'description'             => esc_html__( 'Display a custom slide.', 'rion' ),
					'as_parent'               => array( 'only' => 'vc_single_image,rion_banner,rion_iconbox,rion_testimonials,rion_categories,rion_title' ),
					'content_element'         => true,
					'show_settings_on_create' => true,
					'js_view'                 => 'VcColumnView',
					'icon'                    => RION_SHORTCODES_ICONS_URI . 'slide.png',
					'params'                  => array(
                        array(
                            'type'        => 'textfield',
                            'heading'     => esc_html__( 'Title', 'rion' ),
                            'param_name'  => 'title',
                            'admin_label' => true,
                        ),
						/* Owl */
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Yes', 'rion' ) => 'true',
								esc_html__( 'No', 'rion' )  => 'false',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'AutoPlay', 'rion' ),
							'param_name'  => 'autoplay',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'No', 'rion' )  => 'false',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Navigation', 'rion' ),
							'param_name'  => 'navigation',
							'description' => esc_html__( "Show buton 'next' and 'prev' buttons.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Center', 'rion' )  => '',
								esc_html__( 'Center Square', 'rion' ) => 'nav-center-square',
								esc_html__( 'Right', 'rion' ) => 'nav-right',
							),
							'std'         => '',
							'heading'     => esc_html__( 'Navigation type', 'rion' ),
							'param_name'  => 'nav_type',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							'dependency'  => array(
								'element' => 'navigation',
								'value'   => array( 'true' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'No', 'rion' )  => 'false',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Enable Dots', 'rion' ),
							'param_name'  => 'dots',
							'description' => esc_html__( "Show buton dots.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Default', 'rion' )  => '',
								esc_html__( 'Light', 'rion' ) => 'dots-light',
								esc_html__( 'Dark', 'rion' ) => 'dots-dark',
							),
							'std'         => '',
							'heading'     => esc_html__( 'Dots color', 'rion' ),
							'param_name'  => 'dots_color',
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
							'dependency'  => array(
								'element' => 'dots',
								'value'   => array( 'true' ),
							),
						),
						array(
							'type'        => 'dropdown',
							'value'       => array(
								esc_html__( 'Yes', 'rion' ) => 'true',
								esc_html__( 'No', 'rion' )  => 'false',
							),
							'std'         => 'false',
							'heading'     => esc_html__( 'Loop', 'rion' ),
							'param_name'  => 'loop',
							'description' => esc_html__( "Inifnity loop. Duplicate last and first items to get loop illusion.", 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Slide Speed", 'rion' ),
							"param_name"  => "slidespeed",
							"value"       => "200",
							"description" => esc_html__( 'Slide speed in milliseconds', 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Margin", 'rion' ),
							"param_name"  => "margin",
							"value"       => "30",
							"description" => esc_html__( 'Distance( or space) between 2 item', 'rion' ),
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Auto Responsive Margin', 'rion' ),
							'param_name' => 'autoresponsive',
							'group'      => esc_html__( 'Carousel settings', 'rion' ),
							'value'      => array(
								esc_html__( 'No', 'rion' )  => '',
								esc_html__( 'Yes', 'rion' ) => 'true',
							),
							'std'        => '',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 1500px )", 'rion' ),
							"param_name"  => "ls_items",
							"value"       => "5",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 1200px < 1500px )", 'rion' ),
							"param_name"  => "lg_items",
							"value"       => "4",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on desktop (Screen resolution of device >= 992px < 1200px )", 'rion' ),
							"param_name"  => "md_items",
							"value"       => "3",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on tablet (Screen resolution of device >=768px and < 992px )", 'rion' ),
							"param_name"  => "sm_items",
							"value"       => "2",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on mobile landscape(Screen resolution of device >=480px and < 768px)", 'rion' ),
							"param_name"  => "xs_items",
							"value"       => "2",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "The items on mobile (Screen resolution of device < 480px)", 'rion' ),
							"param_name"  => "ts_items",
							"value"       => "1",
							'group'       => esc_html__( 'Carousel settings', 'rion' ),
							'admin_label' => false,
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							'heading'     => esc_html__( 'Extra Class Name', 'rion' ),
							'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'rion' ),
							'type'        => 'textfield',
							'param_name'  => 'el_class',
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'slider_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);
			/*Section Testimonial*/
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Testimonial', 'rion' ),
					'base'        => 'rion_testimonials', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display testimonial info.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'testimonial.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select Style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'testimonials/style-01.jpg'
								),
                                'style-02' => array(
									'alt' => 'Style 02',
									'img' => RION_SHORTCODE_PREVIEW . 'testimonials/style-02.jpg'
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Star Rating', 'rion' ),
							'param_name' => 'rating',
							'value'      => array(
								esc_html__( '1 Star', 'rion' )  => 'rating-1',
								esc_html__( '2 Stars', 'rion' ) => 'rating-2',
								esc_html__( '3 Stars', 'rion' ) => 'rating-3',
								esc_html__( '4 Stars', 'rion' ) => 'rating-4',
								esc_html__( '5 Stars', 'rion' ) => 'rating-5',
							),
							'std'        => 'rating-5',
							'dependency' => array(
								'element' => 'style',
								'value'   => array( 'style-02'),
							),
						),
						array(
							'type'       => 'textarea',
							'heading'    => esc_html__( 'Content', 'rion' ),
							'param_name' => 'desc',
						),
						array(
							'type'       => 'attach_image',
							'heading'    => esc_html__( 'Image', 'rion' ),
							'param_name' => 'image',
							'dependency' => array(
								'element' => 'style',
								'value'   => array( 'style-02'),
							),
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Name', 'rion' ),
							'param_name'  => 'name',
							'description' => esc_html__( 'Name', 'rion' ),
							'admin_label' => true,
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Position', 'rion' ),
							'param_name'  => 'position',
							'description' => esc_html__( 'Position', 'rion' ),
							'admin_label' => true,
							'dependency' => array(
								'element' => 'style',
								'value'   => array( 'style-02'),
							),
						),
						array(
							'type'       => 'vc_link',
							'heading'    => esc_html__( 'Link', 'rion' ),
							'param_name' => 'link',
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" )
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'testimonials_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						)
					)
				)
			);
			/*Section Team*/
			require_once vc_path_dir( 'CONFIG_DIR', 'content/vc-icon-element.php' );
			$icon_params = array(
				array(
					'type'        => 'textfield',
					'heading'     => esc_html__( 'Link Social', 'rion' ),
					'param_name'  => 'link_social',
					'admin_label' => true,
					'description' => esc_html__( 'shortcode title.', 'rion' ),
				),
			);
			$icon_params = array_merge( $icon_params, (array) vc_map_integrate_shortcode(
				vc_icon_element_params(), 'i_', '',
				array(
					// we need only type, icon_fontawesome, icon_.., NOT color and etc
					'include_only_regex' => '/^(type|icon_\w*)/',
				)
			)
			);
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Team', 'rion' ),
					'base'        => 'rion_team', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display team info.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'testimonial.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select Style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'team/style-01.jpg'
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'       => 'attach_image',
							'heading'    => esc_html__( 'Image', 'rion' ),
							'param_name' => 'image',
						),
						array(
							'type'       => 'param_group',
							'heading'    => esc_html__( 'Social', 'rion' ),
							'param_name' => 'social_team',
							'params'     => $icon_params,
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Name', 'rion' ),
							'param_name'  => 'name',
							'description' => esc_html__( 'Name', 'rion' ),
							'admin_label' => true,
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Position', 'rion' ),
							'param_name'  => 'position',
							'description' => esc_html__( 'Position', 'rion' ),
							'admin_label' => true,
						),
						array(
							'type'       => 'vc_link',
							'heading'    => esc_html__( 'Link', 'rion' ),
							'param_name' => 'link',
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" )
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'team_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						)
					)
				)
			);
			/* Map Google Map */
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Google Map', 'rion' ),
					'base'        => 'rion_googlemap', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a google map.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'gmap.png',
					'params'      => array(
						array(
							"type"        => "attach_image",
							"heading"     => esc_html__( "Pin", "rion" ),
							"param_name"  => "pin_icon",
							"admin_label" => false,
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Title", 'rion' ),
							"param_name"  => "title",
							'admin_label' => true,
							"description" => esc_html__( "title.", 'rion' ),
							'std'         => 'Fami themes',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Phone", 'rion' ),
							"param_name"  => "phone",
							'admin_label' => true,
							"description" => esc_html__( "phone.", 'rion' ),
							'std'         => '088-465 9965 02',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Email", 'rion' ),
							"param_name"  => "email",
							'admin_label' => true,
							"description" => esc_html__( "email.", 'rion' ),
							'std'         => 'famithemes@gmail.com',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Map Height", 'rion' ),
							"param_name"  => "map_height",
							'admin_label' => true,
							'std'         => '400',
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Maps type', 'rion' ),
							'param_name' => 'map_type',
							'value'      => array(
								esc_html__( 'ROADMAP', 'rion' )   => 'ROADMAP',
								esc_html__( 'SATELLITE', 'rion' ) => 'SATELLITE',
								esc_html__( 'HYBRID', 'rion' )    => 'HYBRID',
								esc_html__( 'TERRAIN', 'rion' )   => 'TERRAIN',
							),
							'std'        => 'ROADMAP',
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Show info content?', 'rion' ),
							'param_name' => 'info_content',
							'value'      => array(
								esc_html__( 'Yes', 'rion' ) => '1',
								esc_html__( 'No', 'rion' )  => '2',
							),
							'std'        => '1',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Address", 'rion' ),
							"param_name"  => "address",
							'admin_label' => true,
							"description" => esc_html__( "address.", 'rion' ),
							'std'         => 'New York City, NY, USA',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Longitude", 'rion' ),
							"param_name"  => "longitude",
							'admin_label' => true,
							"description" => esc_html__( "longitude.", 'rion' ),
							'std'         => '-73.935242',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Latitude", 'rion' ),
							"param_name"  => "latitude",
							'admin_label' => true,
							"description" => esc_html__( "latitude.", 'rion' ),
							'std'         => '40.730610',
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Zoom", 'rion' ),
							"param_name"  => "zoom",
							'admin_label' => true,
							"description" => esc_html__( "zoom.", 'rion' ),
							'std'         => '14',
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", 'rion' ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'googlemap_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);

			/* Map New Social */
			$socials     = array();
			$all_socials = rion_get_option( 'user_all_social' );
			$i           = 1;
			if ( $all_socials ) {
				foreach ( $all_socials as $social ) {
					$socials[ $social['title_social'] ] = $i ++;
				}
			}
			vc_map(
				array(
					'name'        => esc_html__( 'Rion: Socials', 'rion' ),
					'base'        => 'rion_socials', // shortcode
					'class'       => '',
					'category'    => esc_html__( 'Rion Elements', 'rion' ),
					'description' => esc_html__( 'Display a social list.', 'rion' ),
					'icon'        => RION_SHORTCODES_ICONS_URI . 'socials.png',
					'params'      => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'socials/style-01.jpg',
								),
								'style-02' => array(
									'alt' => 'Style 02',
									'img' => RION_SHORTCODE_PREVIEW . 'socials/style-02.jpg',
								),
                                'style-03' => array(
									'alt' => 'Style 03',
									'img' => RION_SHORTCODE_PREVIEW . 'socials/style-03.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'       => 'checkbox',
							'heading'    => esc_html__( 'Display on', 'rion' ),
							'param_name' => 'use_socials',
							'class'      => 'checkbox-display-block',
							'value'      => $socials,
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							"type"        => "textfield",
							"heading"     => esc_html__( "Extra class name", "rion" ),
							"param_name"  => "el_class",
							"description" => esc_html__( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "rion" ),
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'Css', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),
						array(
							'param_name'       => 'socials_custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
					),
				)
			);

			/* Pin Mapper */
			$all_pin_mappers      = get_posts(
				array(
					'post_type'      => 'rion_mapper',
					'posts_per_page' => '-1'
				)
			);
			$all_pin_mappers_args = array(
				esc_html__( ' ---- Choose a pin mapper ---- ', 'rion' ) => '0',
			);
			if ( ! empty( $all_pin_mappers ) ) {
				foreach ( $all_pin_mappers as $pin_mapper ) {
					$all_pin_mappers_args[ $pin_mapper->post_title ] = $pin_mapper->ID;
				}
			} else {
				$all_pin_mappers_args = array(
					esc_html__( ' ---- No pin mapper to choose ---- ', 'rion' ) => '0',
				);
			}
			vc_map(
				array(
					'name'     => esc_html__( 'Rion: Pin Mapper', 'rion' ),
					'base'     => 'rion_pinmap',
					'category' => esc_html__( 'Rion Elements', 'rion' ),
					'icon'     => RION_SHORTCODES_ICONS_URI . 'pinmapper.png',
					'params'   => array(
						array(
							'type'        => 'select_preview',
							'heading'     => esc_html__( 'Select style', 'rion' ),
							'value'       => array(
								'style-01' => array(
									'alt' => 'Style 01',
									'img' => RION_SHORTCODE_PREVIEW . 'pinmapper/style-01.jpg',
								),
								'style-02' => array(
									'alt' => 'Style 02',
									'img' => RION_SHORTCODE_PREVIEW . 'pinmapper/style-02.jpg',
								),
							),
							'default'     => 'style-01',
							'admin_label' => true,
							'param_name'  => 'style',
						),
						array(
							'type'       => 'textarea',
							'heading'    => esc_html__( 'Title', 'rion' ),
							'param_name' => 'title',
							'dependency'  => array(
								'element' => 'style',
								'value'   => array(
									'style-02',
								),
							),
						),
						array(
							'type'        => 'textarea',
							'heading'     => esc_html__( 'Short Description', 'rion' ),
							'param_name'  => 'short_desc',
							'description' => esc_html__( 'Short description display under the title', 'rion' ),
							'admin_label' => true,
							'std'         => '',
							'dependency'  => array(
								'element' => 'style',
								'value'   => array(
									'style-02',
								),
							),
						),
						array(
							'type'       => 'vc_link',
							'heading'    => esc_html__( 'Button Link', 'rion' ),
							'param_name' => 'link',
							'dependency'  => array(
								'element' => 'style',
								'value'   => array(
									'style-02',
								),
							),
						),
						array(
							'type'       => 'dropdown',
							'heading'    => esc_html__( 'Choose Pin Mapper', 'rion' ),
							'param_name' => 'ids',
							'value'      => $all_pin_mappers_args
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'animate_on_scroll',
							'heading'    => esc_html__( 'Animation On Scroll', 'rion' ),
							'value'      => $this->animation_on_scroll(),
							'std'        => ''
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Extra class name', 'rion' ),
							'param_name'  => 'el_class',
							'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'rion' ),
						),
						array(
							'param_name'       => 'custom_id',
							'heading'          => esc_html__( 'Hidden ID', 'rion' ),
							'type'             => 'uniqid',
							'edit_field_class' => 'hidden',
						),
						array(
							'type'       => 'css_editor',
							'heading'    => esc_html__( 'CSS box', 'rion' ),
							'param_name' => 'css',
							'group'      => esc_html__( 'Design Options', 'rion' ),
						),

					),
				)
			);

		}
	}

	new Rion_Visual_Composer();
}

if ( class_exists( 'Vc_Manager' ) ) {
	function change_vc_row() {
		$args = array(
			array(
				"type"        => "checkbox",
				"group"       => "Additions",
				"holder"      => "div",
				"class"       => "custom-checkbox",
				"heading"     => esc_html__( 'Parallax effect: ', 'rion' ),
				"description" => esc_html__( 'Chosen for using Paralax scroll', 'rion' ),
				"param_name"  => "paralax_class",
				'admin_label' => true,
				"value"       => array(
					esc_html__( 'paralax-slide', 'rion' ) => "type_paralax",
				),
			),
			array(
				"type"        => "checkbox",
				"group"       => "Additions",
				"heading"     => esc_html__( 'Slide Class: ', 'rion' ),
				"description" => esc_html__( 'Chosen for using slide scroll', 'rion' ),
				"param_name"  => "section_class",
				'admin_label' => true,
				"value"       => array(
					esc_html__( 'section-slide', 'rion' ) => "section-slide",
				),
			),
		);
		foreach ( $args as $value ) {
			// vc_add_param( "vc_row", $value );
			vc_add_param( "vc_section", $value );
		}
	}

	change_vc_row();
	get_template_part( 'vc_templates/vc_row.php' );
	get_template_part( 'vc_templates/vc_section.php' );
}

VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_VC_Tta_Accordion' );

class WPBakeryShortCode_Rion_Tabs extends WPBakeryShortCode_VC_Tta_Accordion {
}

class WPBakeryShortCode_Rion_Accordions extends WPBakeryShortCode_VC_Tta_Accordion {
}

class WPBakeryShortCode_Rion_Container extends WPBakeryShortCodesContainer {
}

class WPBakeryShortCode_Rion_Slider extends WPBakeryShortCodesContainer {
}

class WPBakeryShortCode_rion_Instagramshopwrap extends WPBakeryShortCodesContainer {
}
