<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link    https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Rion
 */

get_header();
$term_id       = get_queried_object_id();
$sidebar_isset = wp_get_sidebars_widgets();

/* Blog Layout */
$rion_blog_layout       = rion_get_option( 'rion_blog_layout', 'left' );
$rion_blog_style        = rion_get_option( 'blog-style', 'standard' );
$rion_blog_used_sidebar = rion_get_option( 'blog_sidebar', 'primary_sidebar' );
$rion_container_class   = array( 'main-container' );

if ( is_single() ) {
	
	/*Single post layout*/
	$rion_blog_layout       = rion_get_option( 'sidebar_single_post_position', 'left' );
	$rion_blog_used_sidebar = rion_get_option( 'single_post_sidebar', 'primary_sidebar' );
}

if ( isset( $sidebar_isset[ $rion_blog_used_sidebar ] ) && empty( $sidebar_isset[ $rion_blog_used_sidebar ] ) ) {
	$rion_blog_layout = 'full';
}

if ( $rion_blog_layout == 'full' ) {
	$rion_container_class[] = 'no-sidebar';
} else {
	$rion_container_class[] = $rion_blog_layout . '-sidebar has-sidebar';
}

$rion_content_class   = array();
$rion_content_class[] = 'main-content';

if ( $rion_blog_layout == 'full' ) {
	$rion_content_class[] = 'col-sm-12 col-xs-12';
} else {
	$rion_content_class[] = 'col-lg-9 col-md-8 col-sm-12 col-xs-12';
}

$rion_sidebar_class   = array();
$rion_sidebar_class[] = 'sidebar';

if ( $rion_blog_layout != 'full' ) {
	$rion_sidebar_class[] = 'col-lg-3 col-md-4 col-sm-12 col-xs-12';
}

?>
<div class="<?php echo esc_attr( implode( ' ', $rion_container_class ) ); ?>">
    <!-- POST LAYOUT -->
	<?php if ( is_single() ) { ?>
        <div class="rion-breadcrumb">
            <div class="container">
			    <?php get_template_part( 'template-parts/part', 'breadcrumb' ); ?>
            </div>
        </div>
	<?php } ?>
    <div class="container">
        <div class="row">
            <div class="<?php echo esc_attr( implode( ' ', $rion_content_class ) ); ?>">
				<?php
				if ( is_single() ) {
					while ( have_posts() ): the_post();
						get_template_part( 'templates/blog/blog', 'single' );
						/*If comments are open or we have at least one comment, load up the comment template.*/
						if ( comments_open() || get_comments_number() ) :
							comments_template();
						endif;
					endwhile;
					wp_reset_postdata();
				} else {
					get_template_part( 'templates/blog/blog', $rion_blog_style );
				} ?>
            </div>
			<?php if ( $rion_blog_layout != 'full' ): ?>
                <div class="<?php echo esc_attr( implode( ' ', $rion_sidebar_class ) ); ?>">
					<?php get_sidebar(); ?>
                </div>
			<?php endif; ?>
        </div>
    </div>
</div>
<?php get_footer(); ?>

